@@ -11,20 +11,37 @@ has 'required';
 
 has 'default';
 has 'name';
-has 'regex';
 has 'type';
+has 'regex';
+has 'desc';
 
 sub new {
     my ($class, %args) = @_;
     my $self = bless {}, $class;
 
     $self->{named} = $args{named};
-    $self->{required} = $args{param}[0] =~ /^require(s|d)$/ ? 1 : 0;
+    $self->{required} = $args{type} =~ /^require(s|d)$/ ? 1 : 0;
+
+    $self->_parse($args{spec});
 
-    @$self{qw(name type default regex)} = @{ $args{param}[1] };
     $self;
 }
 
+sub _parse {
+    my ($self, $spec) = @_;
+
+    my @keys = qw(name type default regex desc);
+
+    if (ref($spec) eq 'ARRAY') {
+        #TODO: $self->app->log($e);
+        carp 'Deprecated parameters definition syntax. Use hashref syntax instead.';
+        @$self{@keys} = @$spec;
+    }
+    elsif (ref($spec) eq 'HASH') {
+        $self->{$_} = $spec->{$_} for @keys;
+    }
+}
+
 sub validate {
     my ($self, $ref_value, $quiet) = @_;
 
@@ -59,7 +76,7 @@ sub validate {
         if ($e) {
             unless ($quiet) {
                 #TODO: $self->app->log($e);
-                carp "CHECK: `$self->{name}` has invalid value `$v`!";
+                carp "Param: `$self->{name}` has invalid value `$v`!";
                 carp $e;
             }
             return;
@@ -67,7 +84,7 @@ sub validate {
 
         # Param check
         if ($self->regex && $v !~ $self->regex) {
-            carp "REGEX: `$self->{name}` has invalid value `$v`!" unless $quiet;
+            carp "Param: regex failed; `$self->{name}` has invalid value `$v`!" unless $quiet;
             return;
         }
     }
@@ -89,30 +106,34 @@ Raisin::Param - Parameter class for Raisin.
 
 Parameter class for L<Raisin>. Validates request paramters.
 
-=head3 required { shift->{required} }
+=head3 default
 
-Returns C<true> if it's required parameter.
+Returns default value if exists or C<undef>.
 
-=head3 named
+=head3 desc
 
-Returns C<true> if it's path parameter.
+Returns parameter description.
 
 =head3 name
 
 Returns parameter name.
 
-=head3 type
+=head3 named
 
-Returns paramter type object.
-
-=head3 default
-
-Returns default value if exists or C<undef>.
+Returns C<true> if it's path parameter.
 
 =head3 regex
 
 Return paramter regex if exists or C<undef>.
 
+=head3 required { shift->{required} }
+
+Returns C<true> if it's required parameter.
+
+=head3 type
+
+Returns paramter type object.
+
 =head3 validate
 
 Process and validate parameter. Takes B<reference> as the input paramter.
