@@ -5,6 +5,7 @@ use warnings;
 
 use base 'Raisin::Plugin';
 
+use Carp qw(carp);
 use POSIX qw(strftime);
 use Plack::Util;
 use Time::HiRes qw(time);
@@ -12,15 +13,15 @@ use Time::HiRes qw(time);
 sub build {
     my ($self, %args) = @_;
 
-    my $module = 'Log::Dispatch';
+    my $logger = $args{fallback} ? 'Raisin::Logger' : 'Log::Dispatch';
 
-    if (delete $args{fallback}) {
-        $module = qw(Raisin::Logger);
-    }
+    my $obj;
+    eval { $obj = Plack::Util::load_class($logger) } || do {
+        carp 'Can\'t load `Log::Dispatch. Fallback to `Raisin::Logger`!';
+        $obj = Plack::Util::load_class('Raisin::Logger');
+    };
 
-    my $class = Plack::Util::load_class($module);
-
-    $self->{logger} = $class->new(%args);
+    $self->{logger} = $obj->new(%args);
 
     $self->register(log => sub {
         shift if ref($_[0]);
@@ -29,20 +30,18 @@ sub build {
 }
 
 sub message {
-    my ($self, $level, @messages) = @_;
+    my ($self, $level, $message, @args) = @_;
 
-    for (@messages) {
-        my $t = time;
-        my $ts = strftime "%d/%b/%Y %H:%M:%S", localtime $t;
-        $ts .= sprintf ".%03d", ($t - int($t)) * 1000;
+    my $t = time;
+    my $ts = strftime "%Y-%m-%dT%H:%M:%S", localtime $t;
+    $ts .= sprintf ".%03d", ($t - int($t)) * 1000;
 
-        my $str = ref($_) ? Dumper($_) : $_;
+    my $str = ref($message) ? Dumper($message) : $message;
 
-        $self->{logger}->log(
-            level   => $level,
-            message => "$ts: $str\n",
-        );
-    }
+    $self->{logger}->log(
+        level   => $level,
+        message => "$ts $str\n",
+    );
 }
 
 1;
